import os

import pytest

ROOT = os.path.abspath(os.path.dirname(__file__))


@pytest.fixture
def rchain_host():
    return os.environ.get('RCHAIN_GRPC_HOST')


@pytest.fixture
def add_contract_path():
    return os.path.join(ROOT, 'add1.rho')



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

import repl_pb2 as repl__pb2


class ReplStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Run = channel.unary_unary(
        '/coop.rchain.node.model.Repl/Run',
        request_serializer=repl__pb2.CmdRequest.SerializeToString,
        response_deserializer=repl__pb2.ReplResponse.FromString,
        )
    self.Eval = channel.unary_unary(
        '/coop.rchain.node.model.Repl/Eval',
        request_serializer=repl__pb2.EvalRequest.SerializeToString,
        response_deserializer=repl__pb2.ReplResponse.FromString,
        )


class ReplServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Run(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Eval(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ReplServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Run': grpc.unary_unary_rpc_method_handler(
          servicer.Run,
          request_deserializer=repl__pb2.CmdRequest.FromString,
          response_serializer=repl__pb2.ReplResponse.SerializeToString,
      ),
      'Eval': grpc.unary_unary_rpc_method_handler(
          servicer.Eval,
          request_deserializer=repl__pb2.EvalRequest.FromString,
          response_serializer=repl__pb2.ReplResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'coop.rchain.node.model.Repl', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# unify difference between python 3.7 and 3.6
import sys
from typing import Union

from google.protobuf.pyext._message import (RepeatedCompositeContainer,
                                            RepeatedScalarContainer)

container_classes = [RepeatedCompositeContainer, RepeatedScalarContainer]
IContainer = Union[RepeatedCompositeContainer, RepeatedScalarContainer]

if sys.version_info >= (3, 7):
    from google.protobuf.internal.containers import (
        RepeatedCompositeFieldContainer,
        RepeatedScalarFieldContainer,
    )

    container_classes.extend(
        (RepeatedCompositeFieldContainer, RepeatedScalarFieldContainer)
    )
    IContainer = Union[
        RepeatedCompositeContainer,
        RepeatedScalarContainer,
        RepeatedCompositeFieldContainer,
        RepeatedScalarFieldContainer,
    ]



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: RhoTypes.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='RhoTypes.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\022coop.rchain.models\342?\254\001\0326coop.rchain.models.BitSetBytesMapper.bitSetBytesMapper\0328coop.rchain.models.ParSetTypeMapper.parSetESetTypeMapper\0328coop.rchain.models.ParMapTypeMapper.parMapEMapTypeMapper'),
  serialized_pb=_b('\n\x0eRhoTypes.proto\x1a\x15scalapb/scalapb.proto\"\xc4\x02\n\x03Par\x12\x14\n\x05sends\x18\x01 \x03(\x0b\x32\x05.Send\x12\x1a\n\x08receives\x18\x02 \x03(\x0b\x32\x08.Receive\x12\x12\n\x04news\x18\x04 \x03(\x0b\x32\x04.New\x12\x14\n\x05\x65xprs\x18\x05 \x03(\x0b\x32\x05.Expr\x12\x17\n\x07matches\x18\x06 \x03(\x0b\x32\x06.Match\x12\x16\n\x03ids\x18\x07 \x03(\x0b\x32\t.GPrivate\x12\x18\n\x07\x62undles\x18\x0b \x03(\x0b\x32\x07.Bundle\x12 \n\x0b\x63onnectives\x18\x08 \x03(\x0b\x32\x0b.Connective\x12[\n\x0blocallyFree\x18\t \x01(\x0c\x42\x46\xe2?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]\x12\x17\n\x0f\x63onnective_used\x18\n \x01(\x08\"a\n\x12TaggedContinuation\x12\"\n\x08par_body\x18\x01 \x01(\x0b\x32\x0e.ParWithRandomH\x00\x12\x18\n\x0escala_body_ref\x18\x02 \x01(\x03H\x00\x42\r\n\x0btagged_cont\"o\n\rParWithRandom\x12\x1a\n\x04\x62ody\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x42\n\x0brandomState\x18\x02 \x01(\x0c\x42-\xe2?*\n(coop.rchain.crypto.hash.Blake2b512Random\")\n\x05PCost\x12\x12\n\niterations\x18\x01 \x01(\x05\x12\x0c\n\x04\x63ost\x18\x02 \x01(\x04\"k\n\x11ListParWithRandom\x12\x12\n\x04pars\x18\x01 \x03(\x0b\x32\x04.Par\x12\x42\n\x0brandomState\x18\x02 \x01(\x0c\x42-\xe2?*\n(coop.rchain.crypto.hash.Blake2b512Random\"\x81\x01\n\x19ListParWithRandomAndPhlos\x12\x12\n\x04pars\x18\x01 \x03(\x0b\x32\x04.Par\x12\x42\n\x0brandomState\x18\x02 \x01(\x0c\x42-\xe2?*\n(coop.rchain.crypto.hash.Blake2b512Random\x12\x0c\n\x04\x63ost\x18\x03 \x01(\x04\"s\n\x03Var\x12\x13\n\tbound_var\x18\x01 \x01(\x11H\x00\x12\x12\n\x08\x66ree_var\x18\x02 \x01(\x11H\x00\x12$\n\x08wildcard\x18\x03 \x01(\x0b\x32\x10.Var.WildcardMsgH\x00\x1a\r\n\x0bWildcardMsgB\x0e\n\x0cvar_instance\"I\n\x06\x42undle\x12\x1a\n\x04\x62ody\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x11\n\twriteFlag\x18\x02 \x01(\x08\x12\x10\n\x08readFlag\x18\x03 \x01(\x08\"\xc0\x01\n\x04Send\x12\x1a\n\x04\x63han\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x04.Par\x12\x12\n\npersistent\x18\x03 \x01(\x08\x12[\n\x0blocallyFree\x18\x05 \x01(\x0c\x42\x46\xe2?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]\x12\x17\n\x0f\x63onnective_used\x18\x06 \x01(\x08\"o\n\x0bReceiveBind\x12\x16\n\x08patterns\x18\x01 \x03(\x0b\x32\x04.Par\x12\x1c\n\x06source\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x17\n\tremainder\x18\x03 \x01(\x0b\x32\x04.Var\x12\x11\n\tfreeCount\x18\x04 \x01(\x05\"Q\n\x0b\x42indPattern\x12\x16\n\x08patterns\x18\x01 \x03(\x0b\x32\x04.Par\x12\x17\n\tremainder\x18\x02 \x01(\x0b\x32\x04.Var\x12\x11\n\tfreeCount\x18\x03 \x01(\x05\"2\n\x10ListBindPatterns\x12\x1e\n\x08patterns\x18\x01 \x03(\x0b\x32\x0c.BindPattern\"\xdf\x01\n\x07Receive\x12\x1b\n\x05\x62inds\x18\x01 \x03(\x0b\x32\x0c.ReceiveBind\x12\x1a\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x12\n\npersistent\x18\x03 \x01(\x08\x12\x11\n\tbindCount\x18\x04 \x01(\x05\x12[\n\x0blocallyFree\x18\x06 \x01(\x0c\x42\x46\xe2?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]\x12\x17\n\x0f\x63onnective_used\x18\x07 \x01(\x08\"\x9b\x01\n\x03New\x12\x11\n\tbindCount\x18\x01 \x01(\x11\x12\x17\n\x01p\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x0b\n\x03uri\x18\x03 \x03(\t\x12[\n\x0blocallyFree\x18\x04 \x01(\x0c\x42\x46\xe2?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]\"[\n\tMatchCase\x12\x1d\n\x07pattern\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x1c\n\x06source\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x11\n\tfreeCount\x18\x03 \x01(\x05\"\xb6\x01\n\x05Match\x12\x1c\n\x06target\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x19\n\x05\x63\x61ses\x18\x02 \x03(\x0b\x32\n.MatchCase\x12[\n\x0blocallyFree\x18\x04 \x01(\x0c\x42\x46\xe2?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]\x12\x17\n\x0f\x63onnective_used\x18\x05 \x01(\x08\"\xb4\x07\n\x04\x45xpr\x12\x10\n\x06g_bool\x18\x01 \x01(\x08H\x00\x12\x0f\n\x05g_int\x18\x02 \x01(\x12H\x00\x12\x12\n\x08g_string\x18\x03 \x01(\tH\x00\x12\x0f\n\x05g_uri\x18\x04 \x01(\tH\x00\x12\x16\n\x0cg_byte_array\x18\x19 \x01(\x0cH\x00\x12\x1b\n\ne_not_body\x18\x05 \x01(\x0b\x32\x05.ENotH\x00\x12\x1b\n\ne_neg_body\x18\x06 \x01(\x0b\x32\x05.ENegH\x00\x12\x1d\n\x0b\x65_mult_body\x18\x07 \x01(\x0b\x32\x06.EMultH\x00\x12\x1b\n\ne_div_body\x18\x08 \x01(\x0b\x32\x05.EDivH\x00\x12\x1d\n\x0b\x65_plus_body\x18\t \x01(\x0b\x32\x06.EPlusH\x00\x12\x1f\n\x0c\x65_minus_body\x18\n \x01(\x0b\x32\x07.EMinusH\x00\x12\x19\n\te_lt_body\x18\x0b \x01(\x0b\x32\x04.ELtH\x00\x12\x1b\n\ne_lte_body\x18\x0c \x01(\x0b\x32\x05.ELteH\x00\x12\x19\n\te_gt_body\x18\r \x01(\x0b\x32\x04.EGtH\x00\x12\x1b\n\ne_gte_body\x18\x0e \x01(\x0b\x32\x05.EGteH\x00\x12\x19\n\te_eq_body\x18\x0f \x01(\x0b\x32\x04.EEqH\x00\x12\x1b\n\ne_neq_body\x18\x10 \x01(\x0b\x32\x05.ENeqH\x00\x12\x1b\n\ne_and_body\x18\x11 \x01(\x0b\x32\x05.EAndH\x00\x12\x19\n\te_or_body\x18\x12 \x01(\x0b\x32\x04.EOrH\x00\x12\x1b\n\ne_var_body\x18\x13 \x01(\x0b\x32\x05.EVarH\x00\x12\x1d\n\x0b\x65_list_body\x18\x14 \x01(\x0b\x32\x06.EListH\x00\x12\x1f\n\x0c\x65_tuple_body\x18\x15 \x01(\x0b\x32\x07.ETupleH\x00\x12;\n\ne_set_body\x18\x16 \x01(\x0b\x32\x05.ESetB\x1e\xe2?\x1b\n\x19\x63oop.rchain.models.ParSetH\x00\x12;\n\ne_map_body\x18\x17 \x01(\x0b\x32\x05.EMapB\x1e\xe2?\x1b\n\x19\x63oop.rchain.models.ParMapH\x00\x12!\n\re_method_body\x18\x18 \x01(\x0b\x32\x08.EMethodH\x00\x12#\n\x0e\x65_matches_body\x18\x1b \x01(\x0b\x32\t.EMatchesH\x00\x12\x32\n\x16\x65_percent_percent_body\x18\x1c \x01(\x0b\x32\x10.EPercentPercentH\x00\x12&\n\x10\x65_plus_plus_body\x18\x1d \x01(\x0b\x32\n.EPlusPlusH\x00\x12*\n\x12\x65_minus_minus_body\x18\x1e \x01(\x0b\x32\x0c.EMinusMinusH\x00\x42\x0f\n\rexpr_instance\"\xa8\x01\n\x05\x45List\x12\x10\n\x02ps\x18\x01 \x03(\x0b\x32\x04.Par\x12[\n\x0blocallyFree\x18\x03 \x01(\x0c\x42\x46\xe2?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]\x12\x17\n\x0f\x63onnective_used\x18\x04 \x01(\x08\x12\x17\n\tremainder\x18\x05 \x01(\x0b\x32\x04.Var\"\x90\x01\n\x06\x45Tuple\x12\x10\n\x02ps\x18\x01 \x03(\x0b\x32\x04.Par\x12[\n\x0blocallyFree\x18\x03 \x01(\x0c\x42\x46\xe2?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]\x12\x17\n\x0f\x63onnective_used\x18\x04 \x01(\x08\"\xa7\x01\n\x04\x45Set\x12\x10\n\x02ps\x18\x01 \x03(\x0b\x32\x04.Par\x12[\n\x0blocallyFree\x18\x03 \x01(\x0c\x42\x46\xe2?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]\x12\x17\n\x0f\x63onnective_used\x18\x04 \x01(\x08\x12\x17\n\tremainder\x18\x05 \x01(\x0b\x32\x04.Var\"\xb1\x01\n\x04\x45Map\x12\x1a\n\x03kvs\x18\x01 \x03(\x0b\x32\r.KeyValuePair\x12[\n\x0blocallyFree\x18\x03 \x01(\x0c\x42\x46\xe2?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]\x12\x17\n\x0f\x63onnective_used\x18\x04 \x01(\x08\x12\x17\n\tremainder\x18\x05 \x01(\x0b\x32\x04.Var\"\xca\x01\n\x07\x45Method\x12\x12\n\nmethodName\x18\x01 \x01(\t\x12\x1c\n\x06target\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x17\n\targuments\x18\x03 \x03(\x0b\x32\x04.Par\x12[\n\x0blocallyFree\x18\x05 \x01(\x0c\x42\x46\xe2?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]\x12\x17\n\x0f\x63onnective_used\x18\x06 \x01(\x08\"F\n\x0cKeyValuePair\x12\x19\n\x03key\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\"\x1f\n\x04\x45Var\x12\x17\n\x01v\x18\x01 \x01(\x0b\x32\x04.VarB\x06\xe2?\x03\xf0\x01\x01\"\x1f\n\x04\x45Not\x12\x17\n\x01p\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\"\x1f\n\x04\x45Neg\x12\x17\n\x01p\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\";\n\x05\x45Mult\x12\x18\n\x02p1\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x18\n\x02p2\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\":\n\x04\x45\x44iv\x12\x18\n\x02p1\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x18\n\x02p2\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\";\n\x05\x45Plus\x12\x18\n\x02p1\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x18\n\x02p2\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\"<\n\x06\x45Minus\x12\x18\n\x02p1\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x18\n\x02p2\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\"9\n\x03\x45Lt\x12\x18\n\x02p1\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x18\n\x02p2\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\":\n\x04\x45Lte\x12\x18\n\x02p1\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x18\n\x02p2\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\"9\n\x03\x45Gt\x12\x18\n\x02p1\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x18\n\x02p2\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\":\n\x04\x45Gte\x12\x18\n\x02p1\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x18\n\x02p2\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\"9\n\x03\x45\x45q\x12\x18\n\x02p1\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x18\n\x02p2\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\":\n\x04\x45Neq\x12\x18\n\x02p1\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x18\n\x02p2\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\":\n\x04\x45\x41nd\x12\x18\n\x02p1\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x18\n\x02p2\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\"9\n\x03\x45Or\x12\x18\n\x02p1\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x18\n\x02p2\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\"G\n\x08\x45Matches\x12\x1c\n\x06target\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x1d\n\x07pattern\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\"E\n\x0f\x45PercentPercent\x12\x18\n\x02p1\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x18\n\x02p2\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\"?\n\tEPlusPlus\x12\x18\n\x02p1\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x18\n\x02p2\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\"A\n\x0b\x45MinusMinus\x12\x18\n\x02p1\x18\x01 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\x12\x18\n\x02p2\x18\x02 \x01(\x0b\x32\x04.ParB\x06\xe2?\x03\xf0\x01\x01\"\xa5\x02\n\nConnective\x12(\n\rconn_and_body\x18\x01 \x01(\x0b\x32\x0f.ConnectiveBodyH\x00\x12\'\n\x0c\x63onn_or_body\x18\x02 \x01(\x0b\x32\x0f.ConnectiveBodyH\x00\x12\x1d\n\rconn_not_body\x18\x03 \x01(\x0b\x32\x04.ParH\x00\x12\x1f\n\x0cvar_ref_body\x18\x04 \x01(\x0b\x32\x07.VarRefH\x00\x12\x13\n\tconn_bool\x18\x05 \x01(\x08H\x00\x12\x12\n\x08\x63onn_int\x18\x06 \x01(\x08H\x00\x12\x15\n\x0b\x63onn_string\x18\x07 \x01(\x08H\x00\x12\x12\n\x08\x63onn_uri\x18\x08 \x01(\x08H\x00\x12\x19\n\x0f\x63onn_byte_array\x18\t \x01(\x08H\x00\x42\x15\n\x13\x63onnective_instance\"&\n\x06VarRef\x12\r\n\x05index\x18\x01 \x01(\x11\x12\r\n\x05\x64\x65pth\x18\x02 \x01(\x11\"\"\n\x0e\x43onnectiveBody\x12\x10\n\x02ps\x18\x01 \x03(\x0b\x32\x04.Par\"\x16\n\x08GPrivate\x12\n\n\x02id\x18\x01 \x01(\x0c\x42\xc4\x01\n\x12\x63oop.rchain.models\xe2?\xac\x01\x1a\x36\x63oop.rchain.models.BitSetBytesMapper.bitSetBytesMapper\x1a\x38\x63oop.rchain.models.ParSetTypeMapper.parSetESetTypeMapper\x1a\x38\x63oop.rchain.models.ParMapTypeMapper.parMapEMapTypeMapperb\x06proto3')
  ,
  dependencies=[scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_PAR = _descriptor.Descriptor(
  name='Par',
  full_name='Par',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sends', full_name='Par.sends', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receives', full_name='Par.receives', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='news', full_name='Par.news', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exprs', full_name='Par.exprs', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='matches', full_name='Par.matches', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ids', full_name='Par.ids', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bundles', full_name='Par.bundles', index=6,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connectives', full_name='Par.connectives', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locallyFree', full_name='Par.locallyFree', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connective_used', full_name='Par.connective_used', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=366,
)


_TAGGEDCONTINUATION = _descriptor.Descriptor(
  name='TaggedContinuation',
  full_name='TaggedContinuation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='par_body', full_name='TaggedContinuation.par_body', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scala_body_ref', full_name='TaggedContinuation.scala_body_ref', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='tagged_cont', full_name='TaggedContinuation.tagged_cont',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=368,
  serialized_end=465,
)


_PARWITHRANDOM = _descriptor.Descriptor(
  name='ParWithRandom',
  full_name='ParWithRandom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='ParWithRandom.body', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='randomState', full_name='ParWithRandom.randomState', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?*\n(coop.rchain.crypto.hash.Blake2b512Random'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=467,
  serialized_end=578,
)


_PCOST = _descriptor.Descriptor(
  name='PCost',
  full_name='PCost',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iterations', full_name='PCost.iterations', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost', full_name='PCost.cost', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=621,
)


_LISTPARWITHRANDOM = _descriptor.Descriptor(
  name='ListParWithRandom',
  full_name='ListParWithRandom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pars', full_name='ListParWithRandom.pars', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='randomState', full_name='ListParWithRandom.randomState', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?*\n(coop.rchain.crypto.hash.Blake2b512Random'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=623,
  serialized_end=730,
)


_LISTPARWITHRANDOMANDPHLOS = _descriptor.Descriptor(
  name='ListParWithRandomAndPhlos',
  full_name='ListParWithRandomAndPhlos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pars', full_name='ListParWithRandomAndPhlos.pars', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='randomState', full_name='ListParWithRandomAndPhlos.randomState', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?*\n(coop.rchain.crypto.hash.Blake2b512Random'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost', full_name='ListParWithRandomAndPhlos.cost', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=733,
  serialized_end=862,
)


_VAR_WILDCARDMSG = _descriptor.Descriptor(
  name='WildcardMsg',
  full_name='Var.WildcardMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=950,
  serialized_end=963,
)

_VAR = _descriptor.Descriptor(
  name='Var',
  full_name='Var',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bound_var', full_name='Var.bound_var', index=0,
      number=1, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='free_var', full_name='Var.free_var', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wildcard', full_name='Var.wildcard', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_VAR_WILDCARDMSG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='var_instance', full_name='Var.var_instance',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=864,
  serialized_end=979,
)


_BUNDLE = _descriptor.Descriptor(
  name='Bundle',
  full_name='Bundle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='Bundle.body', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writeFlag', full_name='Bundle.writeFlag', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='readFlag', full_name='Bundle.readFlag', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=981,
  serialized_end=1054,
)


_SEND = _descriptor.Descriptor(
  name='Send',
  full_name='Send',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chan', full_name='Send.chan', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='Send.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='Send.persistent', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locallyFree', full_name='Send.locallyFree', index=3,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connective_used', full_name='Send.connective_used', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1057,
  serialized_end=1249,
)


_RECEIVEBIND = _descriptor.Descriptor(
  name='ReceiveBind',
  full_name='ReceiveBind',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='patterns', full_name='ReceiveBind.patterns', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='ReceiveBind.source', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remainder', full_name='ReceiveBind.remainder', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='freeCount', full_name='ReceiveBind.freeCount', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1251,
  serialized_end=1362,
)


_BINDPATTERN = _descriptor.Descriptor(
  name='BindPattern',
  full_name='BindPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='patterns', full_name='BindPattern.patterns', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remainder', full_name='BindPattern.remainder', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='freeCount', full_name='BindPattern.freeCount', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1364,
  serialized_end=1445,
)


_LISTBINDPATTERNS = _descriptor.Descriptor(
  name='ListBindPatterns',
  full_name='ListBindPatterns',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='patterns', full_name='ListBindPatterns.patterns', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1447,
  serialized_end=1497,
)


_RECEIVE = _descriptor.Descriptor(
  name='Receive',
  full_name='Receive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='binds', full_name='Receive.binds', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='Receive.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='Receive.persistent', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bindCount', full_name='Receive.bindCount', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locallyFree', full_name='Receive.locallyFree', index=4,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connective_used', full_name='Receive.connective_used', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1500,
  serialized_end=1723,
)


_NEW = _descriptor.Descriptor(
  name='New',
  full_name='New',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bindCount', full_name='New.bindCount', index=0,
      number=1, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p', full_name='New.p', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='New.uri', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locallyFree', full_name='New.locallyFree', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1726,
  serialized_end=1881,
)


_MATCHCASE = _descriptor.Descriptor(
  name='MatchCase',
  full_name='MatchCase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pattern', full_name='MatchCase.pattern', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='MatchCase.source', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='freeCount', full_name='MatchCase.freeCount', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1883,
  serialized_end=1974,
)


_MATCH = _descriptor.Descriptor(
  name='Match',
  full_name='Match',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='Match.target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cases', full_name='Match.cases', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locallyFree', full_name='Match.locallyFree', index=2,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connective_used', full_name='Match.connective_used', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1977,
  serialized_end=2159,
)


_EXPR = _descriptor.Descriptor(
  name='Expr',
  full_name='Expr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='g_bool', full_name='Expr.g_bool', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='g_int', full_name='Expr.g_int', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='g_string', full_name='Expr.g_string', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='g_uri', full_name='Expr.g_uri', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='g_byte_array', full_name='Expr.g_byte_array', index=4,
      number=25, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_not_body', full_name='Expr.e_not_body', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_neg_body', full_name='Expr.e_neg_body', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_mult_body', full_name='Expr.e_mult_body', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_div_body', full_name='Expr.e_div_body', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_plus_body', full_name='Expr.e_plus_body', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_minus_body', full_name='Expr.e_minus_body', index=10,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_lt_body', full_name='Expr.e_lt_body', index=11,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_lte_body', full_name='Expr.e_lte_body', index=12,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_gt_body', full_name='Expr.e_gt_body', index=13,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_gte_body', full_name='Expr.e_gte_body', index=14,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_eq_body', full_name='Expr.e_eq_body', index=15,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_neq_body', full_name='Expr.e_neq_body', index=16,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_and_body', full_name='Expr.e_and_body', index=17,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_or_body', full_name='Expr.e_or_body', index=18,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_var_body', full_name='Expr.e_var_body', index=19,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_list_body', full_name='Expr.e_list_body', index=20,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_tuple_body', full_name='Expr.e_tuple_body', index=21,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_set_body', full_name='Expr.e_set_body', index=22,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\033\n\031coop.rchain.models.ParSet'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_map_body', full_name='Expr.e_map_body', index=23,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\033\n\031coop.rchain.models.ParMap'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_method_body', full_name='Expr.e_method_body', index=24,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_matches_body', full_name='Expr.e_matches_body', index=25,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_percent_percent_body', full_name='Expr.e_percent_percent_body', index=26,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_plus_plus_body', full_name='Expr.e_plus_plus_body', index=27,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e_minus_minus_body', full_name='Expr.e_minus_minus_body', index=28,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='expr_instance', full_name='Expr.expr_instance',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2162,
  serialized_end=3110,
)


_ELIST = _descriptor.Descriptor(
  name='EList',
  full_name='EList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ps', full_name='EList.ps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locallyFree', full_name='EList.locallyFree', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connective_used', full_name='EList.connective_used', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remainder', full_name='EList.remainder', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3113,
  serialized_end=3281,
)


_ETUPLE = _descriptor.Descriptor(
  name='ETuple',
  full_name='ETuple',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ps', full_name='ETuple.ps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locallyFree', full_name='ETuple.locallyFree', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connective_used', full_name='ETuple.connective_used', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3284,
  serialized_end=3428,
)


_ESET = _descriptor.Descriptor(
  name='ESet',
  full_name='ESet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ps', full_name='ESet.ps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locallyFree', full_name='ESet.locallyFree', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connective_used', full_name='ESet.connective_used', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remainder', full_name='ESet.remainder', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3431,
  serialized_end=3598,
)


_EMAP = _descriptor.Descriptor(
  name='EMap',
  full_name='EMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='kvs', full_name='EMap.kvs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locallyFree', full_name='EMap.locallyFree', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connective_used', full_name='EMap.connective_used', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remainder', full_name='EMap.remainder', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3601,
  serialized_end=3778,
)


_EMETHOD = _descriptor.Descriptor(
  name='EMethod',
  full_name='EMethod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='methodName', full_name='EMethod.methodName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='EMethod.target', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='EMethod.arguments', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locallyFree', full_name='EMethod.locallyFree', index=3,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?C\nAcoop.rchain.models.AlwaysEqual[scala.collection.immutable.BitSet]'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connective_used', full_name='EMethod.connective_used', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3781,
  serialized_end=3983,
)


_KEYVALUEPAIR = _descriptor.Descriptor(
  name='KeyValuePair',
  full_name='KeyValuePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='KeyValuePair.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='KeyValuePair.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3985,
  serialized_end=4055,
)


_EVAR = _descriptor.Descriptor(
  name='EVar',
  full_name='EVar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='v', full_name='EVar.v', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4057,
  serialized_end=4088,
)


_ENOT = _descriptor.Descriptor(
  name='ENot',
  full_name='ENot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p', full_name='ENot.p', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4090,
  serialized_end=4121,
)


_ENEG = _descriptor.Descriptor(
  name='ENeg',
  full_name='ENeg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p', full_name='ENeg.p', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4123,
  serialized_end=4154,
)


_EMULT = _descriptor.Descriptor(
  name='EMult',
  full_name='EMult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p1', full_name='EMult.p1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2', full_name='EMult.p2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4156,
  serialized_end=4215,
)


_EDIV = _descriptor.Descriptor(
  name='EDiv',
  full_name='EDiv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p1', full_name='EDiv.p1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2', full_name='EDiv.p2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4217,
  serialized_end=4275,
)


_EPLUS = _descriptor.Descriptor(
  name='EPlus',
  full_name='EPlus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p1', full_name='EPlus.p1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2', full_name='EPlus.p2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4277,
  serialized_end=4336,
)


_EMINUS = _descriptor.Descriptor(
  name='EMinus',
  full_name='EMinus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p1', full_name='EMinus.p1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2', full_name='EMinus.p2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4338,
  serialized_end=4398,
)


_ELT = _descriptor.Descriptor(
  name='ELt',
  full_name='ELt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p1', full_name='ELt.p1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2', full_name='ELt.p2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4400,
  serialized_end=4457,
)


_ELTE = _descriptor.Descriptor(
  name='ELte',
  full_name='ELte',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p1', full_name='ELte.p1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2', full_name='ELte.p2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4459,
  serialized_end=4517,
)


_EGT = _descriptor.Descriptor(
  name='EGt',
  full_name='EGt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p1', full_name='EGt.p1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2', full_name='EGt.p2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4519,
  serialized_end=4576,
)


_EGTE = _descriptor.Descriptor(
  name='EGte',
  full_name='EGte',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p1', full_name='EGte.p1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2', full_name='EGte.p2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4578,
  serialized_end=4636,
)


_EEQ = _descriptor.Descriptor(
  name='EEq',
  full_name='EEq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p1', full_name='EEq.p1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2', full_name='EEq.p2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4638,
  serialized_end=4695,
)


_ENEQ = _descriptor.Descriptor(
  name='ENeq',
  full_name='ENeq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p1', full_name='ENeq.p1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2', full_name='ENeq.p2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4697,
  serialized_end=4755,
)


_EAND = _descriptor.Descriptor(
  name='EAnd',
  full_name='EAnd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p1', full_name='EAnd.p1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2', full_name='EAnd.p2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4757,
  serialized_end=4815,
)


_EOR = _descriptor.Descriptor(
  name='EOr',
  full_name='EOr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p1', full_name='EOr.p1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2', full_name='EOr.p2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4817,
  serialized_end=4874,
)


_EMATCHES = _descriptor.Descriptor(
  name='EMatches',
  full_name='EMatches',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='EMatches.target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pattern', full_name='EMatches.pattern', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4876,
  serialized_end=4947,
)


_EPERCENTPERCENT = _descriptor.Descriptor(
  name='EPercentPercent',
  full_name='EPercentPercent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p1', full_name='EPercentPercent.p1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2', full_name='EPercentPercent.p2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4949,
  serialized_end=5018,
)


_EPLUSPLUS = _descriptor.Descriptor(
  name='EPlusPlus',
  full_name='EPlusPlus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p1', full_name='EPlusPlus.p1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2', full_name='EPlusPlus.p2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5020,
  serialized_end=5083,
)


_EMINUSMINUS = _descriptor.Descriptor(
  name='EMinusMinus',
  full_name='EMinusMinus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p1', full_name='EMinusMinus.p1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2', full_name='EMinusMinus.p2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\003\360\001\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5085,
  serialized_end=5150,
)


_CONNECTIVE = _descriptor.Descriptor(
  name='Connective',
  full_name='Connective',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='conn_and_body', full_name='Connective.conn_and_body', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conn_or_body', full_name='Connective.conn_or_body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conn_not_body', full_name='Connective.conn_not_body', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='var_ref_body', full_name='Connective.var_ref_body', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conn_bool', full_name='Connective.conn_bool', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conn_int', full_name='Connective.conn_int', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conn_string', full_name='Connective.conn_string', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conn_uri', full_name='Connective.conn_uri', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conn_byte_array', full_name='Connective.conn_byte_array', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='connective_instance', full_name='Connective.connective_instance',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=5153,
  serialized_end=5446,
)


_VARREF = _descriptor.Descriptor(
  name='VarRef',
  full_name='VarRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='VarRef.index', index=0,
      number=1, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='depth', full_name='VarRef.depth', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5448,
  serialized_end=5486,
)


_CONNECTIVEBODY = _descriptor.Descriptor(
  name='ConnectiveBody',
  full_name='ConnectiveBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ps', full_name='ConnectiveBody.ps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5488,
  serialized_end=5522,
)


_GPRIVATE = _descriptor.Descriptor(
  name='GPrivate',
  full_name='GPrivate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='GPrivate.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5524,
  serialized_end=5546,
)

_PAR.fields_by_name['sends'].message_type = _SEND
_PAR.fields_by_name['receives'].message_type = _RECEIVE
_PAR.fields_by_name['news'].message_type = _NEW
_PAR.fields_by_name['exprs'].message_type = _EXPR
_PAR.fields_by_name['matches'].message_type = _MATCH
_PAR.fields_by_name['ids'].message_type = _GPRIVATE
_PAR.fields_by_name['bundles'].message_type = _BUNDLE
_PAR.fields_by_name['connectives'].message_type = _CONNECTIVE
_TAGGEDCONTINUATION.fields_by_name['par_body'].message_type = _PARWITHRANDOM
_TAGGEDCONTINUATION.oneofs_by_name['tagged_cont'].fields.append(
  _TAGGEDCONTINUATION.fields_by_name['par_body'])
_TAGGEDCONTINUATION.fields_by_name['par_body'].containing_oneof = _TAGGEDCONTINUATION.oneofs_by_name['tagged_cont']
_TAGGEDCONTINUATION.oneofs_by_name['tagged_cont'].fields.append(
  _TAGGEDCONTINUATION.fields_by_name['scala_body_ref'])
_TAGGEDCONTINUATION.fields_by_name['scala_body_ref'].containing_oneof = _TAGGEDCONTINUATION.oneofs_by_name['tagged_cont']
_PARWITHRANDOM.fields_by_name['body'].message_type = _PAR
_LISTPARWITHRANDOM.fields_by_name['pars'].message_type = _PAR
_LISTPARWITHRANDOMANDPHLOS.fields_by_name['pars'].message_type = _PAR
_VAR_WILDCARDMSG.containing_type = _VAR
_VAR.fields_by_name['wildcard'].message_type = _VAR_WILDCARDMSG
_VAR.oneofs_by_name['var_instance'].fields.append(
  _VAR.fields_by_name['bound_var'])
_VAR.fields_by_name['bound_var'].containing_oneof = _VAR.oneofs_by_name['var_instance']
_VAR.oneofs_by_name['var_instance'].fields.append(
  _VAR.fields_by_name['free_var'])
_VAR.fields_by_name['free_var'].containing_oneof = _VAR.oneofs_by_name['var_instance']
_VAR.oneofs_by_name['var_instance'].fields.append(
  _VAR.fields_by_name['wildcard'])
_VAR.fields_by_name['wildcard'].containing_oneof = _VAR.oneofs_by_name['var_instance']
_BUNDLE.fields_by_name['body'].message_type = _PAR
_SEND.fields_by_name['chan'].message_type = _PAR
_SEND.fields_by_name['data'].message_type = _PAR
_RECEIVEBIND.fields_by_name['patterns'].message_type = _PAR
_RECEIVEBIND.fields_by_name['source'].message_type = _PAR
_RECEIVEBIND.fields_by_name['remainder'].message_type = _VAR
_BINDPATTERN.fields_by_name['patterns'].message_type = _PAR
_BINDPATTERN.fields_by_name['remainder'].message_type = _VAR
_LISTBINDPATTERNS.fields_by_name['patterns'].message_type = _BINDPATTERN
_RECEIVE.fields_by_name['binds'].message_type = _RECEIVEBIND
_RECEIVE.fields_by_name['body'].message_type = _PAR
_NEW.fields_by_name['p'].message_type = _PAR
_MATCHCASE.fields_by_name['pattern'].message_type = _PAR
_MATCHCASE.fields_by_name['source'].message_type = _PAR
_MATCH.fields_by_name['target'].message_type = _PAR
_MATCH.fields_by_name['cases'].message_type = _MATCHCASE
_EXPR.fields_by_name['e_not_body'].message_type = _ENOT
_EXPR.fields_by_name['e_neg_body'].message_type = _ENEG
_EXPR.fields_by_name['e_mult_body'].message_type = _EMULT
_EXPR.fields_by_name['e_div_body'].message_type = _EDIV
_EXPR.fields_by_name['e_plus_body'].message_type = _EPLUS
_EXPR.fields_by_name['e_minus_body'].message_type = _EMINUS
_EXPR.fields_by_name['e_lt_body'].message_type = _ELT
_EXPR.fields_by_name['e_lte_body'].message_type = _ELTE
_EXPR.fields_by_name['e_gt_body'].message_type = _EGT
_EXPR.fields_by_name['e_gte_body'].message_type = _EGTE
_EXPR.fields_by_name['e_eq_body'].message_type = _EEQ
_EXPR.fields_by_name['e_neq_body'].message_type = _ENEQ
_EXPR.fields_by_name['e_and_body'].message_type = _EAND
_EXPR.fields_by_name['e_or_body'].message_type = _EOR
_EXPR.fields_by_name['e_var_body'].message_type = _EVAR
_EXPR.fields_by_name['e_list_body'].message_type = _ELIST
_EXPR.fields_by_name['e_tuple_body'].message_type = _ETUPLE
_EXPR.fields_by_name['e_set_body'].message_type = _ESET
_EXPR.fields_by_name['e_map_body'].message_type = _EMAP
_EXPR.fields_by_name['e_method_body'].message_type = _EMETHOD
_EXPR.fields_by_name['e_matches_body'].message_type = _EMATCHES
_EXPR.fields_by_name['e_percent_percent_body'].message_type = _EPERCENTPERCENT
_EXPR.fields_by_name['e_plus_plus_body'].message_type = _EPLUSPLUS
_EXPR.fields_by_name['e_minus_minus_body'].message_type = _EMINUSMINUS
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['g_bool'])
_EXPR.fields_by_name['g_bool'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['g_int'])
_EXPR.fields_by_name['g_int'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['g_string'])
_EXPR.fields_by_name['g_string'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['g_uri'])
_EXPR.fields_by_name['g_uri'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['g_byte_array'])
_EXPR.fields_by_name['g_byte_array'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_not_body'])
_EXPR.fields_by_name['e_not_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_neg_body'])
_EXPR.fields_by_name['e_neg_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_mult_body'])
_EXPR.fields_by_name['e_mult_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_div_body'])
_EXPR.fields_by_name['e_div_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_plus_body'])
_EXPR.fields_by_name['e_plus_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_minus_body'])
_EXPR.fields_by_name['e_minus_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_lt_body'])
_EXPR.fields_by_name['e_lt_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_lte_body'])
_EXPR.fields_by_name['e_lte_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_gt_body'])
_EXPR.fields_by_name['e_gt_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_gte_body'])
_EXPR.fields_by_name['e_gte_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_eq_body'])
_EXPR.fields_by_name['e_eq_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_neq_body'])
_EXPR.fields_by_name['e_neq_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_and_body'])
_EXPR.fields_by_name['e_and_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_or_body'])
_EXPR.fields_by_name['e_or_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_var_body'])
_EXPR.fields_by_name['e_var_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_list_body'])
_EXPR.fields_by_name['e_list_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_tuple_body'])
_EXPR.fields_by_name['e_tuple_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_set_body'])
_EXPR.fields_by_name['e_set_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_map_body'])
_EXPR.fields_by_name['e_map_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_method_body'])
_EXPR.fields_by_name['e_method_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_matches_body'])
_EXPR.fields_by_name['e_matches_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_percent_percent_body'])
_EXPR.fields_by_name['e_percent_percent_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_plus_plus_body'])
_EXPR.fields_by_name['e_plus_plus_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_EXPR.oneofs_by_name['expr_instance'].fields.append(
  _EXPR.fields_by_name['e_minus_minus_body'])
_EXPR.fields_by_name['e_minus_minus_body'].containing_oneof = _EXPR.oneofs_by_name['expr_instance']
_ELIST.fields_by_name['ps'].message_type = _PAR
_ELIST.fields_by_name['remainder'].message_type = _VAR
_ETUPLE.fields_by_name['ps'].message_type = _PAR
_ESET.fields_by_name['ps'].message_type = _PAR
_ESET.fields_by_name['remainder'].message_type = _VAR
_EMAP.fields_by_name['kvs'].message_type = _KEYVALUEPAIR
_EMAP.fields_by_name['remainder'].message_type = _VAR
_EMETHOD.fields_by_name['target'].message_type = _PAR
_EMETHOD.fields_by_name['arguments'].message_type = _PAR
_KEYVALUEPAIR.fields_by_name['key'].message_type = _PAR
_KEYVALUEPAIR.fields_by_name['value'].message_type = _PAR
_EVAR.fields_by_name['v'].message_type = _VAR
_ENOT.fields_by_name['p'].message_type = _PAR
_ENEG.fields_by_name['p'].message_type = _PAR
_EMULT.fields_by_name['p1'].message_type = _PAR
_EMULT.fields_by_name['p2'].message_type = _PAR
_EDIV.fields_by_name['p1'].message_type = _PAR
_EDIV.fields_by_name['p2'].message_type = _PAR
_EPLUS.fields_by_name['p1'].message_type = _PAR
_EPLUS.fields_by_name['p2'].message_type = _PAR
_EMINUS.fields_by_name['p1'].message_type = _PAR
_EMINUS.fields_by_name['p2'].message_type = _PAR
_ELT.fields_by_name['p1'].message_type = _PAR
_ELT.fields_by_name['p2'].message_type = _PAR
_ELTE.fields_by_name['p1'].message_type = _PAR
_ELTE.fields_by_name['p2'].message_type = _PAR
_EGT.fields_by_name['p1'].message_type = _PAR
_EGT.fields_by_name['p2'].message_type = _PAR
_EGTE.fields_by_name['p1'].message_type = _PAR
_EGTE.fields_by_name['p2'].message_type = _PAR
_EEQ.fields_by_name['p1'].message_type = _PAR
_EEQ.fields_by_name['p2'].message_type = _PAR
_ENEQ.fields_by_name['p1'].message_type = _PAR
_ENEQ.fields_by_name['p2'].message_type = _PAR
_EAND.fields_by_name['p1'].message_type = _PAR
_EAND.fields_by_name['p2'].message_type = _PAR
_EOR.fields_by_name['p1'].message_type = _PAR
_EOR.fields_by_name['p2'].message_type = _PAR
_EMATCHES.fields_by_name['target'].message_type = _PAR
_EMATCHES.fields_by_name['pattern'].message_type = _PAR
_EPERCENTPERCENT.fields_by_name['p1'].message_type = _PAR
_EPERCENTPERCENT.fields_by_name['p2'].message_type = _PAR
_EPLUSPLUS.fields_by_name['p1'].message_type = _PAR
_EPLUSPLUS.fields_by_name['p2'].message_type = _PAR
_EMINUSMINUS.fields_by_name['p1'].message_type = _PAR
_EMINUSMINUS.fields_by_name['p2'].message_type = _PAR
_CONNECTIVE.fields_by_name['conn_and_body'].message_type = _CONNECTIVEBODY
_CONNECTIVE.fields_by_name['conn_or_body'].message_type = _CONNECTIVEBODY
_CONNECTIVE.fields_by_name['conn_not_body'].message_type = _PAR
_CONNECTIVE.fields_by_name['var_ref_body'].message_type = _VARREF
_CONNECTIVE.oneofs_by_name['connective_instance'].fields.append(
  _CONNECTIVE.fields_by_name['conn_and_body'])
_CONNECTIVE.fields_by_name['conn_and_body'].containing_oneof = _CONNECTIVE.oneofs_by_name['connective_instance']
_CONNECTIVE.oneofs_by_name['connective_instance'].fields.append(
  _CONNECTIVE.fields_by_name['conn_or_body'])
_CONNECTIVE.fields_by_name['conn_or_body'].containing_oneof = _CONNECTIVE.oneofs_by_name['connective_instance']
_CONNECTIVE.oneofs_by_name['connective_instance'].fields.append(
  _CONNECTIVE.fields_by_name['conn_not_body'])
_CONNECTIVE.fields_by_name['conn_not_body'].containing_oneof = _CONNECTIVE.oneofs_by_name['connective_instance']
_CONNECTIVE.oneofs_by_name['connective_instance'].fields.append(
  _CONNECTIVE.fields_by_name['var_ref_body'])
_CONNECTIVE.fields_by_name['var_ref_body'].containing_oneof = _CONNECTIVE.oneofs_by_name['connective_instance']
_CONNECTIVE.oneofs_by_name['connective_instance'].fields.append(
  _CONNECTIVE.fields_by_name['conn_bool'])
_CONNECTIVE.fields_by_name['conn_bool'].containing_oneof = _CONNECTIVE.oneofs_by_name['connective_instance']
_CONNECTIVE.oneofs_by_name['connective_instance'].fields.append(
  _CONNECTIVE.fields_by_name['conn_int'])
_CONNECTIVE.fields_by_name['conn_int'].containing_oneof = _CONNECTIVE.oneofs_by_name['connective_instance']
_CONNECTIVE.oneofs_by_name['connective_instance'].fields.append(
  _CONNECTIVE.fields_by_name['conn_string'])
_CONNECTIVE.fields_by_name['conn_string'].containing_oneof = _CONNECTIVE.oneofs_by_name['connective_instance']
_CONNECTIVE.oneofs_by_name['connective_instance'].fields.append(
  _CONNECTIVE.fields_by_name['conn_uri'])
_CONNECTIVE.fields_by_name['conn_uri'].containing_oneof = _CONNECTIVE.oneofs_by_name['connective_instance']
_CONNECTIVE.oneofs_by_name['connective_instance'].fields.append(
  _CONNECTIVE.fields_by_name['conn_byte_array'])
_CONNECTIVE.fields_by_name['conn_byte_array'].containing_oneof = _CONNECTIVE.oneofs_by_name['connective_instance']
_CONNECTIVEBODY.fields_by_name['ps'].message_type = _PAR
DESCRIPTOR.message_types_by_name['Par'] = _PAR
DESCRIPTOR.message_types_by_name['TaggedContinuation'] = _TAGGEDCONTINUATION
DESCRIPTOR.message_types_by_name['ParWithRandom'] = _PARWITHRANDOM
DESCRIPTOR.message_types_by_name['PCost'] = _PCOST
DESCRIPTOR.message_types_by_name['ListParWithRandom'] = _LISTPARWITHRANDOM
DESCRIPTOR.message_types_by_name['ListParWithRandomAndPhlos'] = _LISTPARWITHRANDOMANDPHLOS
DESCRIPTOR.message_types_by_name['Var'] = _VAR
DESCRIPTOR.message_types_by_name['Bundle'] = _BUNDLE
DESCRIPTOR.message_types_by_name['Send'] = _SEND
DESCRIPTOR.message_types_by_name['ReceiveBind'] = _RECEIVEBIND
DESCRIPTOR.message_types_by_name['BindPattern'] = _BINDPATTERN
DESCRIPTOR.message_types_by_name['ListBindPatterns'] = _LISTBINDPATTERNS
DESCRIPTOR.message_types_by_name['Receive'] = _RECEIVE
DESCRIPTOR.message_types_by_name['New'] = _NEW
DESCRIPTOR.message_types_by_name['MatchCase'] = _MATCHCASE
DESCRIPTOR.message_types_by_name['Match'] = _MATCH
DESCRIPTOR.message_types_by_name['Expr'] = _EXPR
DESCRIPTOR.message_types_by_name['EList'] = _ELIST
DESCRIPTOR.message_types_by_name['ETuple'] = _ETUPLE
DESCRIPTOR.message_types_by_name['ESet'] = _ESET
DESCRIPTOR.message_types_by_name['EMap'] = _EMAP
DESCRIPTOR.message_types_by_name['EMethod'] = _EMETHOD
DESCRIPTOR.message_types_by_name['KeyValuePair'] = _KEYVALUEPAIR
DESCRIPTOR.message_types_by_name['EVar'] = _EVAR
DESCRIPTOR.message_types_by_name['ENot'] = _ENOT
DESCRIPTOR.message_types_by_name['ENeg'] = _ENEG
DESCRIPTOR.message_types_by_name['EMult'] = _EMULT
DESCRIPTOR.message_types_by_name['EDiv'] = _EDIV
DESCRIPTOR.message_types_by_name['EPlus'] = _EPLUS
DESCRIPTOR.message_types_by_name['EMinus'] = _EMINUS
DESCRIPTOR.message_types_by_name['ELt'] = _ELT
DESCRIPTOR.message_types_by_name['ELte'] = _ELTE
DESCRIPTOR.message_types_by_name['EGt'] = _EGT
DESCRIPTOR.message_types_by_name['EGte'] = _EGTE
DESCRIPTOR.message_types_by_name['EEq'] = _EEQ
DESCRIPTOR.message_types_by_name['ENeq'] = _ENEQ
DESCRIPTOR.message_types_by_name['EAnd'] = _EAND
DESCRIPTOR.message_types_by_name['EOr'] = _EOR
DESCRIPTOR.message_types_by_name['EMatches'] = _EMATCHES
DESCRIPTOR.message_types_by_name['EPercentPercent'] = _EPERCENTPERCENT
DESCRIPTOR.message_types_by_name['EPlusPlus'] = _EPLUSPLUS
DESCRIPTOR.message_types_by_name['EMinusMinus'] = _EMINUSMINUS
DESCRIPTOR.message_types_by_name['Connective'] = _CONNECTIVE
DESCRIPTOR.message_types_by_name['VarRef'] = _VARREF
DESCRIPTOR.message_types_by_name['ConnectiveBody'] = _CONNECTIVEBODY
DESCRIPTOR.message_types_by_name['GPrivate'] = _GPRIVATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Par = _reflection.GeneratedProtocolMessageType('Par', (_message.Message,), dict(
  DESCRIPTOR = _PAR,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:Par)
  ))
_sym_db.RegisterMessage(Par)

TaggedContinuation = _reflection.GeneratedProtocolMessageType('TaggedContinuation', (_message.Message,), dict(
  DESCRIPTOR = _TAGGEDCONTINUATION,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:TaggedContinuation)
  ))
_sym_db.RegisterMessage(TaggedContinuation)

ParWithRandom = _reflection.GeneratedProtocolMessageType('ParWithRandom', (_message.Message,), dict(
  DESCRIPTOR = _PARWITHRANDOM,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:ParWithRandom)
  ))
_sym_db.RegisterMessage(ParWithRandom)

PCost = _reflection.GeneratedProtocolMessageType('PCost', (_message.Message,), dict(
  DESCRIPTOR = _PCOST,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:PCost)
  ))
_sym_db.RegisterMessage(PCost)

ListParWithRandom = _reflection.GeneratedProtocolMessageType('ListParWithRandom', (_message.Message,), dict(
  DESCRIPTOR = _LISTPARWITHRANDOM,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:ListParWithRandom)
  ))
_sym_db.RegisterMessage(ListParWithRandom)

ListParWithRandomAndPhlos = _reflection.GeneratedProtocolMessageType('ListParWithRandomAndPhlos', (_message.Message,), dict(
  DESCRIPTOR = _LISTPARWITHRANDOMANDPHLOS,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:ListParWithRandomAndPhlos)
  ))
_sym_db.RegisterMessage(ListParWithRandomAndPhlos)

Var = _reflection.GeneratedProtocolMessageType('Var', (_message.Message,), dict(

  WildcardMsg = _reflection.GeneratedProtocolMessageType('WildcardMsg', (_message.Message,), dict(
    DESCRIPTOR = _VAR_WILDCARDMSG,
    __module__ = 'RhoTypes_pb2'
    # @@protoc_insertion_point(class_scope:Var.WildcardMsg)
    ))
  ,
  DESCRIPTOR = _VAR,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:Var)
  ))
_sym_db.RegisterMessage(Var)
_sym_db.RegisterMessage(Var.WildcardMsg)

Bundle = _reflection.GeneratedProtocolMessageType('Bundle', (_message.Message,), dict(
  DESCRIPTOR = _BUNDLE,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:Bundle)
  ))
_sym_db.RegisterMessage(Bundle)

Send = _reflection.GeneratedProtocolMessageType('Send', (_message.Message,), dict(
  DESCRIPTOR = _SEND,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:Send)
  ))
_sym_db.RegisterMessage(Send)

ReceiveBind = _reflection.GeneratedProtocolMessageType('ReceiveBind', (_message.Message,), dict(
  DESCRIPTOR = _RECEIVEBIND,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:ReceiveBind)
  ))
_sym_db.RegisterMessage(ReceiveBind)

BindPattern = _reflection.GeneratedProtocolMessageType('BindPattern', (_message.Message,), dict(
  DESCRIPTOR = _BINDPATTERN,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:BindPattern)
  ))
_sym_db.RegisterMessage(BindPattern)

ListBindPatterns = _reflection.GeneratedProtocolMessageType('ListBindPatterns', (_message.Message,), dict(
  DESCRIPTOR = _LISTBINDPATTERNS,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:ListBindPatterns)
  ))
_sym_db.RegisterMessage(ListBindPatterns)

Receive = _reflection.GeneratedProtocolMessageType('Receive', (_message.Message,), dict(
  DESCRIPTOR = _RECEIVE,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:Receive)
  ))
_sym_db.RegisterMessage(Receive)

New = _reflection.GeneratedProtocolMessageType('New', (_message.Message,), dict(
  DESCRIPTOR = _NEW,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:New)
  ))
_sym_db.RegisterMessage(New)

MatchCase = _reflection.GeneratedProtocolMessageType('MatchCase', (_message.Message,), dict(
  DESCRIPTOR = _MATCHCASE,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:MatchCase)
  ))
_sym_db.RegisterMessage(MatchCase)

Match = _reflection.GeneratedProtocolMessageType('Match', (_message.Message,), dict(
  DESCRIPTOR = _MATCH,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:Match)
  ))
_sym_db.RegisterMessage(Match)

Expr = _reflection.GeneratedProtocolMessageType('Expr', (_message.Message,), dict(
  DESCRIPTOR = _EXPR,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:Expr)
  ))
_sym_db.RegisterMessage(Expr)

EList = _reflection.GeneratedProtocolMessageType('EList', (_message.Message,), dict(
  DESCRIPTOR = _ELIST,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EList)
  ))
_sym_db.RegisterMessage(EList)

ETuple = _reflection.GeneratedProtocolMessageType('ETuple', (_message.Message,), dict(
  DESCRIPTOR = _ETUPLE,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:ETuple)
  ))
_sym_db.RegisterMessage(ETuple)

ESet = _reflection.GeneratedProtocolMessageType('ESet', (_message.Message,), dict(
  DESCRIPTOR = _ESET,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:ESet)
  ))
_sym_db.RegisterMessage(ESet)

EMap = _reflection.GeneratedProtocolMessageType('EMap', (_message.Message,), dict(
  DESCRIPTOR = _EMAP,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EMap)
  ))
_sym_db.RegisterMessage(EMap)

EMethod = _reflection.GeneratedProtocolMessageType('EMethod', (_message.Message,), dict(
  DESCRIPTOR = _EMETHOD,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EMethod)
  ))
_sym_db.RegisterMessage(EMethod)

KeyValuePair = _reflection.GeneratedProtocolMessageType('KeyValuePair', (_message.Message,), dict(
  DESCRIPTOR = _KEYVALUEPAIR,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:KeyValuePair)
  ))
_sym_db.RegisterMessage(KeyValuePair)

EVar = _reflection.GeneratedProtocolMessageType('EVar', (_message.Message,), dict(
  DESCRIPTOR = _EVAR,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EVar)
  ))
_sym_db.RegisterMessage(EVar)

ENot = _reflection.GeneratedProtocolMessageType('ENot', (_message.Message,), dict(
  DESCRIPTOR = _ENOT,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:ENot)
  ))
_sym_db.RegisterMessage(ENot)

ENeg = _reflection.GeneratedProtocolMessageType('ENeg', (_message.Message,), dict(
  DESCRIPTOR = _ENEG,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:ENeg)
  ))
_sym_db.RegisterMessage(ENeg)

EMult = _reflection.GeneratedProtocolMessageType('EMult', (_message.Message,), dict(
  DESCRIPTOR = _EMULT,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EMult)
  ))
_sym_db.RegisterMessage(EMult)

EDiv = _reflection.GeneratedProtocolMessageType('EDiv', (_message.Message,), dict(
  DESCRIPTOR = _EDIV,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EDiv)
  ))
_sym_db.RegisterMessage(EDiv)

EPlus = _reflection.GeneratedProtocolMessageType('EPlus', (_message.Message,), dict(
  DESCRIPTOR = _EPLUS,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EPlus)
  ))
_sym_db.RegisterMessage(EPlus)

EMinus = _reflection.GeneratedProtocolMessageType('EMinus', (_message.Message,), dict(
  DESCRIPTOR = _EMINUS,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EMinus)
  ))
_sym_db.RegisterMessage(EMinus)

ELt = _reflection.GeneratedProtocolMessageType('ELt', (_message.Message,), dict(
  DESCRIPTOR = _ELT,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:ELt)
  ))
_sym_db.RegisterMessage(ELt)

ELte = _reflection.GeneratedProtocolMessageType('ELte', (_message.Message,), dict(
  DESCRIPTOR = _ELTE,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:ELte)
  ))
_sym_db.RegisterMessage(ELte)

EGt = _reflection.GeneratedProtocolMessageType('EGt', (_message.Message,), dict(
  DESCRIPTOR = _EGT,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EGt)
  ))
_sym_db.RegisterMessage(EGt)

EGte = _reflection.GeneratedProtocolMessageType('EGte', (_message.Message,), dict(
  DESCRIPTOR = _EGTE,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EGte)
  ))
_sym_db.RegisterMessage(EGte)

EEq = _reflection.GeneratedProtocolMessageType('EEq', (_message.Message,), dict(
  DESCRIPTOR = _EEQ,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EEq)
  ))
_sym_db.RegisterMessage(EEq)

ENeq = _reflection.GeneratedProtocolMessageType('ENeq', (_message.Message,), dict(
  DESCRIPTOR = _ENEQ,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:ENeq)
  ))
_sym_db.RegisterMessage(ENeq)

EAnd = _reflection.GeneratedProtocolMessageType('EAnd', (_message.Message,), dict(
  DESCRIPTOR = _EAND,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EAnd)
  ))
_sym_db.RegisterMessage(EAnd)

EOr = _reflection.GeneratedProtocolMessageType('EOr', (_message.Message,), dict(
  DESCRIPTOR = _EOR,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EOr)
  ))
_sym_db.RegisterMessage(EOr)

EMatches = _reflection.GeneratedProtocolMessageType('EMatches', (_message.Message,), dict(
  DESCRIPTOR = _EMATCHES,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EMatches)
  ))
_sym_db.RegisterMessage(EMatches)

EPercentPercent = _reflection.GeneratedProtocolMessageType('EPercentPercent', (_message.Message,), dict(
  DESCRIPTOR = _EPERCENTPERCENT,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EPercentPercent)
  ))
_sym_db.RegisterMessage(EPercentPercent)

EPlusPlus = _reflection.GeneratedProtocolMessageType('EPlusPlus', (_message.Message,), dict(
  DESCRIPTOR = _EPLUSPLUS,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EPlusPlus)
  ))
_sym_db.RegisterMessage(EPlusPlus)

EMinusMinus = _reflection.GeneratedProtocolMessageType('EMinusMinus', (_message.Message,), dict(
  DESCRIPTOR = _EMINUSMINUS,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:EMinusMinus)
  ))
_sym_db.RegisterMessage(EMinusMinus)

Connective = _reflection.GeneratedProtocolMessageType('Connective', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIVE,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:Connective)
  ))
_sym_db.RegisterMessage(Connective)

VarRef = _reflection.GeneratedProtocolMessageType('VarRef', (_message.Message,), dict(
  DESCRIPTOR = _VARREF,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:VarRef)
  ))
_sym_db.RegisterMessage(VarRef)

ConnectiveBody = _reflection.GeneratedProtocolMessageType('ConnectiveBody', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIVEBODY,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:ConnectiveBody)
  ))
_sym_db.RegisterMessage(ConnectiveBody)

GPrivate = _reflection.GeneratedProtocolMessageType('GPrivate', (_message.Message,), dict(
  DESCRIPTOR = _GPRIVATE,
  __module__ = 'RhoTypes_pb2'
  # @@protoc_insertion_point(class_scope:GPrivate)
  ))
_sym_db.RegisterMessage(GPrivate)


DESCRIPTOR._options = None
_PAR.fields_by_name['locallyFree']._options = None
_PARWITHRANDOM.fields_by_name['body']._options = None
_PARWITHRANDOM.fields_by_name['randomState']._options = None
_LISTPARWITHRANDOM.fields_by_name['randomState']._options = None
_LISTPARWITHRANDOMANDPHLOS.fields_by_name['randomState']._options = None
_BUNDLE.fields_by_name['body']._options = None
_SEND.fields_by_name['chan']._options = None
_SEND.fields_by_name['locallyFree']._options = None
_RECEIVEBIND.fields_by_name['source']._options = None
_RECEIVE.fields_by_name['body']._options = None
_RECEIVE.fields_by_name['locallyFree']._options = None
_NEW.fields_by_name['p']._options = None
_NEW.fields_by_name['locallyFree']._options = None
_MATCHCASE.fields_by_name['pattern']._options = None
_MATCHCASE.fields_by_name['source']._options = None
_MATCH.fields_by_name['target']._options = None
_MATCH.fields_by_name['locallyFree']._options = None
_EXPR.fields_by_name['e_set_body']._options = None
_EXPR.fields_by_name['e_map_body']._options = None
_ELIST.fields_by_name['locallyFree']._options = None
_ETUPLE.fields_by_name['locallyFree']._options = None
_ESET.fields_by_name['locallyFree']._options = None
_EMAP.fields_by_name['locallyFree']._options = None
_EMETHOD.fields_by_name['target']._options = None
_EMETHOD.fields_by_name['locallyFree']._options = None
_KEYVALUEPAIR.fields_by_name['key']._options = None
_KEYVALUEPAIR.fields_by_name['value']._options = None
_EVAR.fields_by_name['v']._options = None
_ENOT.fields_by_name['p']._options = None
_ENEG.fields_by_name['p']._options = None
_EMULT.fields_by_name['p1']._options = None
_EMULT.fields_by_name['p2']._options = None
_EDIV.fields_by_name['p1']._options = None
_EDIV.fields_by_name['p2']._options = None
_EPLUS.fields_by_name['p1']._options = None
_EPLUS.fields_by_name['p2']._options = None
_EMINUS.fields_by_name['p1']._options = None
_EMINUS.fields_by_name['p2']._options = None
_ELT.fields_by_name['p1']._options = None
_ELT.fields_by_name['p2']._options = None
_ELTE.fields_by_name['p1']._options = None
_ELTE.fields_by_name['p2']._options = None
_EGT.fields_by_name['p1']._options = None
_EGT.fields_by_name['p2']._options = None
_EGTE.fields_by_name['p1']._options = None
_EGTE.fields_by_name['p2']._options = None
_EEQ.fields_by_name['p1']._options = None
_EEQ.fields_by_name['p2']._options = None
_ENEQ.fields_by_name['p1']._options = None
_ENEQ.fields_by_name['p2']._options = None
_EAND.fields_by_name['p1']._options = None
_EAND.fields_by_name['p2']._options = None
_EOR.fields_by_name['p1']._options = None
_EOR.fields_by_name['p2']._options = None
_EMATCHES.fields_by_name['target']._options = None
_EMATCHES.fields_by_name['pattern']._options = None
_EPERCENTPERCENT.fields_by_name['p1']._options = None
_EPERCENTPERCENT.fields_by_name['p2']._options = None
_EPLUSPLUS.fields_by_name['p1']._options = None
_EPLUSPLUS.fields_by_name['p2']._options = None
_EMINUSMINUS.fields_by_name['p1']._options = None
_EMINUSMINUS.fields_by_name['p2']._options = None
# @@protoc_insertion_point(module_scope)
